@@ -26,6 +26,7 @@ Configuration::Configuration()
 	reverseFMVolumeOrder_ = true;
 	moveCursorToRight_ = false;
 	retrieveChannelState_ = false;
+	enableTranslation_ = true;
 
 	// Edit settings
 	pageJumpLength_ = 4;
@@ -36,6 +37,7 @@ Configuration::Configuration()
 	octUpKey_ = u8"Num+*";
 	octDownKey_ = u8"Num+/";
 	echoKey_ = u8"^";
+	noteEntryLayout_ = QWERTY;
 
 	// Sonud //
 	sndDevice_ = u8"";
@@ -668,6 +670,15 @@ bool Configuration::getRetrieveChannelState() const
 	return retrieveChannelState_;
 }
 
+void Configuration::setEnableTranslation(bool enabled)
+{
+	enableTranslation_ = enabled;
+}
+bool Configuration::getEnableTranslation() const
+{
+	return enableTranslation_;
+}
+
 // Edit settings
 void Configuration::setPageJumpLength(size_t length)
 {
@@ -730,6 +741,16 @@ std::string Configuration::getEchoBufferKey() const
 	return echoKey_;
 }
 
+void Configuration::setNoteEntryLayout(KeyboardLayout layout)
+{
+	noteEntryLayout_ = layout;
+}
+
+Configuration::KeyboardLayout Configuration::getNoteEntryLayout() const
+{
+	return noteEntryLayout_;
+}
+
 // Sound //
 void Configuration::setSoundDevice(std::string device)
 {
