@@ -1,5 +1,6 @@
 #include "instrument_editor_fm_form.hpp"
 #include "ui_instrument_editor_fm_form.h"
+#include <stdexcept>
 #include <QString>
 #include <QPoint>
 #include <QMenu>
@@ -74,7 +75,7 @@ InstrumentEditorFMForm::InstrumentEditorFMForm(int num, QWidget *parent) :
 			case Ui::FMOperatorParameter::ML:		param = FMEnvelopeParameter::ML1;		break;
 			case Ui::FMOperatorParameter::DT:		param = FMEnvelopeParameter::DT1;		break;
 			case Ui::FMOperatorParameter::SSGEG:	param = FMEnvelopeParameter::SSGEG1;	break;
-			default:																break;
+			default:	throw std::invalid_argument("Unexpected FMOperatorParameter.");
 			}
 			bt_.lock()->setEnvelopeFMParameter(ui->envNumSpinBox->value(), param, value);
 			emit envelopeParameterChanged(ui->envNumSpinBox->value(), instNum_);
@@ -115,7 +116,7 @@ InstrumentEditorFMForm::InstrumentEditorFMForm(int num, QWidget *parent) :
 			case Ui::FMOperatorParameter::ML:		param = FMEnvelopeParameter::ML2;		break;
 			case Ui::FMOperatorParameter::DT:		param = FMEnvelopeParameter::DT2;		break;
 			case Ui::FMOperatorParameter::SSGEG:	param = FMEnvelopeParameter::SSGEG2;	break;
-			default:																break;
+			default:	throw std::invalid_argument("Unexpected FMOperatorParameter.");
 			}
 			bt_.lock()->setEnvelopeFMParameter(ui->envNumSpinBox->value(), param, value);
 			emit envelopeParameterChanged(ui->envNumSpinBox->value(), instNum_);
@@ -156,7 +157,7 @@ InstrumentEditorFMForm::InstrumentEditorFMForm(int num, QWidget *parent) :
 			case Ui::FMOperatorParameter::ML:		param = FMEnvelopeParameter::ML3;		break;
 			case Ui::FMOperatorParameter::DT:		param = FMEnvelopeParameter::DT3;		break;
 			case Ui::FMOperatorParameter::SSGEG:	param = FMEnvelopeParameter::SSGEG3;	break;
-			default:																break;
+			default:	throw std::invalid_argument("Unexpected FMOperatorParameter.");
 			}
 			bt_.lock()->setEnvelopeFMParameter(ui->envNumSpinBox->value(), param, value);
 			emit envelopeParameterChanged(ui->envNumSpinBox->value(), instNum_);
@@ -197,7 +198,7 @@ InstrumentEditorFMForm::InstrumentEditorFMForm(int num, QWidget *parent) :
 			case Ui::FMOperatorParameter::ML:		param = FMEnvelopeParameter::ML4;		break;
 			case Ui::FMOperatorParameter::DT:		param = FMEnvelopeParameter::DT4;		break;
 			case Ui::FMOperatorParameter::SSGEG:	param = FMEnvelopeParameter::SSGEG4;	break;
-			default:																break;
+			default:	throw std::invalid_argument("Unexpected FMOperatorParameter.");
 			}
 			bt_.lock()->setEnvelopeFMParameter(ui->envNumSpinBox->value(), param, value);
 			emit envelopeParameterChanged(ui->envNumSpinBox->value(), instNum_);
@@ -579,6 +580,8 @@ ReleaseType InstrumentEditorFMForm::convertReleaseTypeForData(VisualizedInstrume
 		return ReleaseType::ABSOLUTE;
 	case VisualizedInstrumentMacroEditor::ReleaseType::RELATIVE:
 		return ReleaseType::RELATIVE;
+	default:
+		throw std::invalid_argument("Unexpected ReleaseType.");
 	}
 }
 
@@ -593,6 +596,8 @@ VisualizedInstrumentMacroEditor::ReleaseType InstrumentEditorFMForm::convertRele
 		return VisualizedInstrumentMacroEditor::ReleaseType::ABSOLUTE;
 	case ReleaseType::RELATIVE:
 		return VisualizedInstrumentMacroEditor::ReleaseType::RELATIVE;
+	default:
+		throw std::invalid_argument("Unexpected ReleaseType.");
 	}
 }
 
@@ -863,7 +868,7 @@ void InstrumentEditorFMForm::setInstrumentEnvelopeParameters(QString envType, QS
 	QStringList digits = data.split(",");
 
 	std::vector<FMEnvelopeTextType> set = config_.lock()->getFMEnvelopeTextMap().at(envType.toUtf8().toStdString());
-	if (set.size() > digits.size()) {
+	if (static_cast<int>(set.size()) > digits.size()) {
 		QMessageBox::critical(this, tr("Error"), tr("Did not match the clipboard text format with %1.").arg(envType));
 		return;
 	}
@@ -1229,11 +1234,10 @@ void InstrumentEditorFMForm::on_envGroupBox_customContextMenuRequested(const QPo
 	QObject::connect(paste, &QAction::triggered, this, &InstrumentEditorFMForm::pasteEnvelope);
 	paste->setEnabled(QApplication::clipboard()->text().startsWith("FM_ENVELOPE:"));
 	QMenu* pasteFrom = menu.addMenu(tr("Paste envelope From"));
-	for (auto pair : config_.lock()->getFMEnvelopeTextMap()) {
-		QString type = QString::fromUtf8(pair.first.c_str(), pair.first.length());
-		QAction* action = pasteFrom->addAction(type);
-		QObject::connect(action, &QAction::triggered, this, [&, action]{ pasteEnvelopeFrom(action->text()); });
-	}
+	for (auto pair : config_.lock()->getFMEnvelopeTextMap())
+		pasteFrom->addAction(QString::fromUtf8(pair.first.c_str(), pair.first.length()));
+	QObject::connect(pasteFrom, &QMenu::triggered,
+					 this, [&](QAction* action) { pasteEnvelopeFrom(action->text()); });
 
 	menu.exec(globalPos);
 }
