@@ -161,7 +161,9 @@ void OrderListPanel::drawRows(int maxWidth)
 		painter.fillRect(0, rowY, maxWidth, rowFontHeight_, rowColor);
 		// Row number
 		painter.setPen(palette_.lock()->odrRowNumColor);
-		painter.drawText(1, baseY, QString("%1").arg(rowNum, 2, 16, QChar('0')).toUpper());
+		painter.drawText(1, baseY, QString("%1").arg(
+							 rowNum, 2, (config_.lock()->getShowRowNumberInHex() ? 16 : 10), QChar('0')
+							 ).toUpper());
 		// Order data
 		orderRowData_ = bt_->getOrderData(curSongNum_, rowNum);
 		painter.setPen(textColor);
@@ -203,7 +205,9 @@ void OrderListPanel::drawRows(int maxWidth)
 		painter.fillRect(0, rowY, maxWidth, rowFontHeight_, rowColor);
 		// Row number
 		painter.setPen(palette_.lock()->odrRowNumColor);
-		painter.drawText(1, baseY, QString("%1").arg(rowNum, 2, 16, QChar('0')).toUpper());
+		painter.drawText(1, baseY, QString("%1").arg(
+							 rowNum, 2, (config_.lock()->getShowRowNumberInHex() ? 16 : 10), QChar('0')
+							 ).toUpper());
 		// Order data
 		orderRowData_ = bt_->getOrderData(curSongNum_, rowNum);
 		painter.setPen(textColor);
@@ -608,7 +612,7 @@ void OrderListPanel::showContextMenu(const OrderPosition& pos, const QPoint& poi
 		if (pos.row == 0) {
 			moveUp->setEnabled(false);
 		}
-		if (pos.row == bt_->getOrderSize(curSongNum_) - 1) {
+		if (pos.row == static_cast<int>(bt_->getOrderSize(curSongNum_)) - 1) {
 			moveDown->setEnabled(false);
 		}
 	}
@@ -646,7 +650,7 @@ void OrderListPanel::setCurrentOrder(int num) {
 void OrderListPanel::onOrderEdited()
 {
 	// Move cursor
-	size_t s = bt_->getOrderSize(curSongNum_);
+	int s = static_cast<int>(bt_->getOrderSize(curSongNum_));
 	if (s <= curPos_.row) curPos_.row = s - 1;
 
 	emit orderEdited();
@@ -747,7 +751,7 @@ void OrderListPanel::onDuplicatePressed()
 void OrderListPanel::onMoveOrderPressed(bool isUp)
 {
 	if ((isUp && curPos_.row == 0)
-			|| (!isUp && curPos_.row == bt_->getOrderSize(curSongNum_) - 1))
+			|| (!isUp && curPos_.row == static_cast<int>(bt_->getOrderSize(curSongNum_)) - 1))
 		return;
 
 	bt_->MoveOrder(curSongNum_, curPos_.row, isUp);
@@ -796,13 +800,13 @@ bool OrderListPanel::keyPressed(QKeyEvent *event)
 		return true;
 	case Qt::Key_Left:
 		moveCursorToRight(-1);
-		if (event->modifiers().testFlag(Qt::ShiftModifier))
-			setSelectedRectangle(shiftPressedPos_, curPos_);
+		if (event->modifiers().testFlag(Qt::ShiftModifier)) setSelectedRectangle(shiftPressedPos_, curPos_);
+		else onSelectPressed(0);
 		return true;
 	case Qt::Key_Right:
 		moveCursorToRight(1);
-		if (event->modifiers().testFlag(Qt::ShiftModifier))
-			setSelectedRectangle(shiftPressedPos_, curPos_);
+		if (event->modifiers().testFlag(Qt::ShiftModifier)) setSelectedRectangle(shiftPressedPos_, curPos_);
+		else onSelectPressed(0);
 		return true;
 	case Qt::Key_Up:
 		if (bt_->isPlaySong()) {
@@ -810,11 +814,8 @@ bool OrderListPanel::keyPressed(QKeyEvent *event)
 		}
 		else {
 			moveCursorToDown(-1);
-			if (event->modifiers().testFlag(Qt::ShiftModifier)
-					&& shiftPressedPos_.row == curPos_.row) {
-				setSelectedRectangle(shiftPressedPos_, curPos_);
-				return true;
-			}
+			if (event->modifiers().testFlag(Qt::ShiftModifier)) setSelectedRectangle(shiftPressedPos_, curPos_);
+			else onSelectPressed(0);
 			return true;
 		}
 	case Qt::Key_Down:
@@ -823,11 +824,8 @@ bool OrderListPanel::keyPressed(QKeyEvent *event)
 		}
 		else {
 			moveCursorToDown(1);
-			if (event->modifiers().testFlag(Qt::ShiftModifier)
-					&& shiftPressedPos_.row == curPos_.row) {
-				setSelectedRectangle(shiftPressedPos_, curPos_);
-				return true;
-			}
+			if (event->modifiers().testFlag(Qt::ShiftModifier)) setSelectedRectangle(shiftPressedPos_, curPos_);
+			else onSelectPressed(0);
 			return true;
 		}
 	case Qt::Key_Home:
@@ -836,11 +834,8 @@ bool OrderListPanel::keyPressed(QKeyEvent *event)
 		}
 		else {
 			moveCursorToDown(-curPos_.row);
-			if (event->modifiers().testFlag(Qt::ShiftModifier)
-					&& shiftPressedPos_.row == curPos_.row) {
-				setSelectedRectangle(shiftPressedPos_, curPos_);
-				return true;
-			}
+			if (event->modifiers().testFlag(Qt::ShiftModifier)) setSelectedRectangle(shiftPressedPos_, curPos_);
+			else onSelectPressed(0);
 			return true;
 		}
 	case Qt::Key_End:
@@ -850,11 +845,8 @@ bool OrderListPanel::keyPressed(QKeyEvent *event)
 		else {
 			moveCursorToDown(
 						bt_->getOrderSize(curSongNum_) - curPos_.row - 1);
-			if (event->modifiers().testFlag(Qt::ShiftModifier)
-					&& shiftPressedPos_.row == curPos_.row) {
-				setSelectedRectangle(shiftPressedPos_, curPos_);
-				return true;
-			}
+			if (event->modifiers().testFlag(Qt::ShiftModifier)) setSelectedRectangle(shiftPressedPos_, curPos_);
+			else onSelectPressed(0);
 			return true;
 		}
 	case Qt::Key_PageUp:
@@ -863,11 +855,8 @@ bool OrderListPanel::keyPressed(QKeyEvent *event)
 		}
 		else {
 			moveCursorToDown(-config_.lock()->getPageJumpLength());
-			if (event->modifiers().testFlag(Qt::ShiftModifier)
-					&& shiftPressedPos_.row == curPos_.row) {
-				setSelectedRectangle(shiftPressedPos_, curPos_);
-				return true;
-			}
+			if (event->modifiers().testFlag(Qt::ShiftModifier)) setSelectedRectangle(shiftPressedPos_, curPos_);
+			else onSelectPressed(0);
 			return true;
 		}
 	case Qt::Key_PageDown:
@@ -876,11 +865,8 @@ bool OrderListPanel::keyPressed(QKeyEvent *event)
 		}
 		else {
 			moveCursorToDown(config_.lock()->getPageJumpLength());
-			if (event->modifiers().testFlag(Qt::ShiftModifier)
-					&& shiftPressedPos_.row == curPos_.row) {
-				setSelectedRectangle(shiftPressedPos_, curPos_);
-				return true;
-			}
+			if (event->modifiers().testFlag(Qt::ShiftModifier)) setSelectedRectangle(shiftPressedPos_, curPos_);
+			else onSelectPressed(0);
 			return true;
 		}
 	case Qt::Key_Insert:
@@ -892,7 +878,7 @@ bool OrderListPanel::keyPressed(QKeyEvent *event)
 					QPoint(calculateColumnsWidthWithRowNum(leftTrackNum_, curPos_.track), curRowY_ - 8));
 		return true;
 	default:
-		if (!bt_->isJamMode()) {
+		if (!bt_->isJamMode() && event->modifiers().testFlag(Qt::NoModifier)) {
 			return enterOrder(event->key());
 		}
 		return false;
@@ -1023,7 +1009,7 @@ bool OrderListPanel::mouseHoverd(QHoverEvent *event)
 		}
 		else {
 			hovPos_.row = curPos_.row + (pos.y() - curRowY_) / rowFontHeight_;
-			if (hovPos_.row >= bt_->getOrderSize(curSongNum_)) hovPos_.row = -1;
+			if (hovPos_.row >= static_cast<int>(bt_->getOrderSize(curSongNum_))) hovPos_.row = -1;
 		}
 	}
 
@@ -1041,7 +1027,7 @@ bool OrderListPanel::mouseHoverd(QHoverEvent *event)
 			}
 			++i;
 
-			if (i == songStyle_.trackAttribs.size()) {
+			if (i == static_cast<int>(songStyle_.trackAttribs.size())) {
 				hovPos_.track = -1;
 				break;
 			}
