@@ -90,6 +90,8 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 				ctr.appendUint8(instSSG->getPitchEnabled() ? tmp : (0x80 | tmp));
 				break;
 			}
+			case SoundSource::DRUM:
+				break;
 			}
 			ctr.writeUint32(iOfs, ctr.size() - iOfs);
 		}
@@ -293,6 +295,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			switch (release.type) {
 			case ReleaseType::NO_RELEASE:
 				ctr.appendUint8(0x00);
+				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
 			case ReleaseType::FIX:
 				ctr.appendUint8(0x01);
@@ -340,6 +343,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			switch (release.type) {
 			case ReleaseType::NO_RELEASE:
 				ctr.appendUint8(0x00);
+				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
 			case ReleaseType::FIX:
 				ctr.appendUint8(0x01);
@@ -387,6 +391,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			switch (release.type) {
 			case ReleaseType::NO_RELEASE:
 				ctr.appendUint8(0x00);
+				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
 			case ReleaseType::FIX:
 				ctr.appendUint8(0x01);
@@ -434,6 +439,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			switch (release.type) {
 			case ReleaseType::NO_RELEASE:
 				ctr.appendUint8(0x00);
+				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
 			case ReleaseType::FIX:
 				ctr.appendUint8(0x01);
@@ -482,6 +488,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			switch (release.type) {
 			case ReleaseType::NO_RELEASE:
 				ctr.appendUint8(0x00);
+				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
 			case ReleaseType::FIX:
 				ctr.appendUint8(0x01);
@@ -529,6 +536,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			switch (release.type) {
 			case ReleaseType::NO_RELEASE:
 				ctr.appendUint8(0x00);
+				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
 			case ReleaseType::FIX:
 				ctr.appendUint8(0x01);
@@ -576,6 +584,7 @@ void ModuleIO::saveModule(std::string path, std::weak_ptr<Module> mod,
 			switch (release.type) {
 			case ReleaseType::NO_RELEASE:
 				ctr.appendUint8(0x00);
+				// If release.type is NO_RELEASE, then release.begin == -1 so omit to save it.
 				break;
 			case ReleaseType::FIX:
 				ctr.appendUint8(0x01);
@@ -759,6 +768,8 @@ void ModuleIO::loadModule(std::string path, std::weak_ptr<Module> mod,
 size_t ModuleIO::loadModuleSectionInModule(std::weak_ptr<Module> mod, BinaryContainer& ctr,
 										   size_t globCsr, uint32_t version)
 {
+	(void)version;
+
 	size_t modOfs = ctr.readUint32(globCsr);
 	size_t modCsr = globCsr + 4;
 	size_t modTitleLen = ctr.readUint32(modCsr);
@@ -796,6 +807,8 @@ size_t ModuleIO::loadModuleSectionInModule(std::weak_ptr<Module> mod, BinaryCont
 size_t ModuleIO::loadInstrumentSectionInModule(std::weak_ptr<InstrumentsManager> instMan,
 											   BinaryContainer& ctr, size_t globCsr, uint32_t version)
 {
+	(void)version;
+
 	size_t instOfs = ctr.readUint32(globCsr);
 	size_t instCsr = globCsr + 4;
 	uint8_t instCnt = ctr.readUint8(instCsr);
@@ -1821,6 +1834,8 @@ size_t ModuleIO::loadInstrumentPropertyOperatorSequence(FMEnvelopeParameter para
 size_t ModuleIO::loadGrooveSectionInModule(std::weak_ptr<Module> mod, BinaryContainer& ctr,
 										   size_t globCsr, uint32_t version)
 {
+	(void)version;
+
 	size_t grvOfs = ctr.readUint32(globCsr);
 	size_t grvCsr = globCsr + 4;
 	uint8_t cnt = ctr.readUint8(grvCsr++) + 1;
